[ipxe-devel] [PATCH] [src] Fix spelling in comments and debug messages

Stefan Weil sw at weilnetz.de
Fri Jan 4 21:13:19 UTC 2013


Fixes in comments and debug messages:

  indicies -> indices
  transfered -> transferred
  controler -> controller
  psuedo -> pseudo
  occurence -> occurrence
  futher -> further
  paramter -> parameter
  auxilliary -> auxiliary
  arbitary -> arbitrary
  rougly -> roughly
  orignally -> originally
  repsectively -> respectively
  endianess -> endianness
  auxilary -> auxiliary
  continously -> continuously
  proccess -> process
  oportunity -> opportunity
  wih -> with
  beacuse -> because
  promiscous -> promiscuous
  apropriate -> appropriate
  durring -> during
  propper -> proper
  convertion -> conversion
  simmilar -> similar
  surounding -> surrounding
  preample -> preamble
  theese -> these
  sould -> could

Most of these fixes were made using codespell.

Signed-off-by: Stefan Weil <sw at weilnetz.de>
---

Hi Michael,

my last patch was based on the ipxe submodule which is part of QEMU.
I'm sorry that I did not notice that this submodule does not use the
official ipxe git repository and was out of date.

Here is an additional patch which fixes more spelling bugs in
latest ipxe. I excluded include/ipxe/efi.

Stefan
 
 contrib/rom-o-matic/utils.php                   |    2 +-
 contrib/vm/bochsrc.txt                          |    4 ++--
 contrib/vm/serial-console                       |    2 +-
 contrib/vm/serial-console.1                     |    2 +-
 src/arch/i386/drivers/net/undiisr.S             |    2 +-
 src/arch/i386/firmware/pcbios/e820mangler.S     |    2 +-
 src/arch/i386/interface/pxeparent/pxeparent.c   |    2 +-
 src/arch/i386/interface/syslinux/comboot_call.c |    4 ++--
 src/arch/x86/include/valgrind/valgrind.h        |    2 +-
 src/doxygen.cfg                                 |    2 +-
 src/drivers/bus/isapnp.c                        |    2 +-
 src/drivers/infiniband/MT25218_PRM.h            |    6 +++---
 src/drivers/infiniband/MT25408_PRM.h            |    8 ++++----
 src/drivers/net/ath/ath5k/ath5k_desc.c          |   12 ++++++------
 src/drivers/net/ath/ath5k/ath5k_eeprom.c        |    4 ++--
 src/drivers/net/ath/ath5k/ath5k_pcu.c           |    4 ++--
 src/drivers/net/ath/ath5k/ath5k_phy.c           |   24 +++++++++++------------
 src/drivers/net/ath/ath5k/ath5k_reset.c         |    2 +-
 src/drivers/net/ath/ath5k/eeprom.h              |    2 +-
 src/drivers/net/ath/ath5k/reg.h                 |   22 ++++++++++-----------
 20 files changed, 55 insertions(+), 55 deletions(-)

diff --git a/contrib/rom-o-matic/utils.php b/contrib/rom-o-matic/utils.php
index e0e62f4..cb9b934 100644
--- a/contrib/rom-o-matic/utils.php
+++ b/contrib/rom-o-matic/utils.php
@@ -268,7 +268,7 @@ function menubox ( $name, $options, $value )
  * Return html code to create select (menu) form fields
  *
  * Use indices of array of strings as menu choices rather than
- * the values pointed to by the indicies.
+ * the values pointed to by the indices.
  *
  * @param string $flag    name of form variable to set
  * @param array  $options array of strings representing choices
diff --git a/contrib/vm/bochsrc.txt b/contrib/vm/bochsrc.txt
index d0f1250..b5dc27a 100644
--- a/contrib/vm/bochsrc.txt
+++ b/contrib/vm/bochsrc.txt
@@ -754,7 +754,7 @@ parport1: enabled=1, file="parport.out"
 #=======================================================================
 # KEYBOARD_SERIAL_DELAY:
 # Approximate time in microseconds that it takes one character to
-# be transfered from the keyboard to controller over the serial path.
+# be transferred from the keyboard to controller over the serial path.
 # Examples:
 #   keyboard_serial_delay: 200
 #=======================================================================
@@ -933,7 +933,7 @@ keyboard_mapping: enabled=0, map=
 #=======================================================================
 # KEYBOARD_TYPE:
 # Type of keyboard return by a "identify keyboard" command to the
-# keyboard controler. It must be one of "xt", "at" or "mf".
+# keyboard controller. It must be one of "xt", "at" or "mf".
 # Defaults to "mf". It should be ok for almost everybody. A known
 # exception is french macs, that do have a "at"-like keyboard.
 #
diff --git a/contrib/vm/serial-console b/contrib/vm/serial-console
index 5d09876..6f99ff2 100755
--- a/contrib/vm/serial-console
+++ b/contrib/vm/serial-console
@@ -64,7 +64,7 @@ C<serial-console> window) to the specified file.
 =item B<-r,--rcfile FILE>
 
 Modify the specified bochsrc file.  The file will be updated to
-contain the path to the slave side of the psuedo tty that we create.
+contain the path to the slave side of the pseudo tty that we create.
 The original file will be restored when C<serial-console> exits.  The
 default is to modify the file C<bochsrc.txt> in the current directory.
 
diff --git a/contrib/vm/serial-console.1 b/contrib/vm/serial-console.1
index 6d19a7d..a233940 100644
--- a/contrib/vm/serial-console.1
+++ b/contrib/vm/serial-console.1
@@ -183,7 +183,7 @@ Log all output (i.e. everything that is printed in the
 .IP "\fB\-r,\-\-rcfile \s-1FILE\s0\fR" 4
 .IX Item "-r,--rcfile FILE"
 Modify the specified bochsrc file.  The file will be updated to
-contain the path to the slave side of the psuedo tty that we create.
+contain the path to the slave side of the pseudo tty that we create.
 The original file will be restored when \f(CW\*(C`serial\-console\*(C'\fR exits.  The
 default is to modify the file \f(CW\*(C`bochsrc.txt\*(C'\fR in the current directory.
 .Sp
diff --git a/src/arch/i386/drivers/net/undiisr.S b/src/arch/i386/drivers/net/undiisr.S
index b27effe..7e2bdd8 100644
--- a/src/arch/i386/drivers/net/undiisr.S
+++ b/src/arch/i386/drivers/net/undiisr.S
@@ -48,7 +48,7 @@ undiisr:
 	cmpw	$PXENV_UNDI_ISR_OUT_OURS, funcflag
 	jne	eoi
 	
-trig:	/* Record interrupt occurence */
+trig:	/* Record interrupt occurrence */
 	incb	undiisr_trigger_count
 
 eoi:	/* Send EOI */
diff --git a/src/arch/i386/firmware/pcbios/e820mangler.S b/src/arch/i386/firmware/pcbios/e820mangler.S
index cea17ef..f53a911 100644
--- a/src/arch/i386/firmware/pcbios/e820mangler.S
+++ b/src/arch/i386/firmware/pcbios/e820mangler.S
@@ -486,7 +486,7 @@ get_mangled_e820:
 	popal
 	jnc	99f /* There are further nonempty regions */
 
-	/* No futher nonempty regions: zero %ebx and clear CF */
+	/* No further nonempty regions: zero %ebx and clear CF */
 	xorl	%ebx, %ebx
 	
 99:	/* Return */
diff --git a/src/arch/i386/interface/pxeparent/pxeparent.c b/src/arch/i386/interface/pxeparent/pxeparent.c
index 8b2a2c8..bea42c5 100644
--- a/src/arch/i386/interface/pxeparent/pxeparent.c
+++ b/src/arch/i386/interface/pxeparent/pxeparent.c
@@ -100,7 +100,7 @@ pxeparent_function_name ( unsigned int function ) {
 /**
  * PXE parent parameter block
  *
- * Used as the paramter block for all parent PXE API calls.  Resides in base
+ * Used as the parameter block for all parent PXE API calls.  Resides in base
  * memory.
  */
 static union u_PXENV_ANY __bss16 ( pxeparent_params );
diff --git a/src/arch/i386/interface/syslinux/comboot_call.c b/src/arch/i386/interface/syslinux/comboot_call.c
index fbf605f..3a8ce7b 100644
--- a/src/arch/i386/interface/syslinux/comboot_call.c
+++ b/src/arch/i386/interface/syslinux/comboot_call.c
@@ -635,13 +635,13 @@ static __asmcall void int22 ( struct i386_all_regs *ix86 ) {
 
 		break;
 
-	case 0x001C: /* Get pointer to auxilliary data vector */
+	case 0x001C: /* Get pointer to auxiliary data vector */
 		/* FIXME: stub */
 		ix86->regs.cx = 0; /* Size of the ADV */
 		ix86->flags &= ~CF;
 		break;
 
-	case 0x001D: /* Write auxilliary data vector */
+	case 0x001D: /* Write auxiliary data vector */
 		/* FIXME: stub */
 		ix86->flags &= ~CF;
 		break;
diff --git a/src/arch/x86/include/valgrind/valgrind.h b/src/arch/x86/include/valgrind/valgrind.h
index d72754b..5492cf3 100644
--- a/src/arch/x86/include/valgrind/valgrind.h
+++ b/src/arch/x86/include/valgrind/valgrind.h
@@ -4243,7 +4243,7 @@ VALGRIND_PRINTF_BACKTRACE(const char *format, ...)
 
 
 /* These requests allow control to move from the simulated CPU to the
-   real CPU, calling an arbitary function.
+   real CPU, calling an arbitrary function.
    
    Note that the current ThreadId is inserted as the first argument.
    So this call:
diff --git a/src/doxygen.cfg b/src/doxygen.cfg
index 4fc9f1e..a348445 100644
--- a/src/doxygen.cfg
+++ b/src/doxygen.cfg
@@ -272,7 +272,7 @@ TYPEDEF_HIDES_STRUCT   = NO
 # causing a significant performance penality. 
 # If the system has enough physical memory increasing the cache will improve the 
 # performance by keeping more symbols in memory. Note that the value works on 
-# a logarithmic scale so increasing the size by one will rougly double the 
+# a logarithmic scale so increasing the size by one will roughly double the 
 # memory usage. The cache size is given by this formula: 
 # 2^(16+SYMBOL_CACHE_SIZE). The valid range is 0..9, the default is 0, 
 # corresponding to a cache size of 2^16 = 65536 symbols
diff --git a/src/drivers/bus/isapnp.c b/src/drivers/bus/isapnp.c
index 6417c74..42cd8e5 100644
--- a/src/drivers/bus/isapnp.c
+++ b/src/drivers/bus/isapnp.c
@@ -38,7 +38,7 @@
  *
  * ISAPnP bus support
  *
- * Etherboot orignally gained ISAPnP support in a very limited way for
+ * Etherboot originally gained ISAPnP support in a very limited way for
  * the 3c515 NIC.  The current implementation is almost a complete
  * rewrite based on the ISAPnP specification, with passing reference
  * to the Linux ISAPnP code.
diff --git a/src/drivers/infiniband/MT25218_PRM.h b/src/drivers/infiniband/MT25218_PRM.h
index 4011bd0..0817609 100644
--- a/src/drivers/infiniband/MT25218_PRM.h
+++ b/src/drivers/infiniband/MT25218_PRM.h
@@ -860,7 +860,7 @@ struct arbelprm_performance_monitors_st {	/* Little Endian */
 /* -------------- */
     pseudo_bit_t	event_counter1[0x00020];
 /* -------------- */
-    pseudo_bit_t	event_counter2[0x00020];/* Read/write event counter, counting events specified by EvCntl and EvCnt2 fields repsectively. When the event counter reaches is maximum value of 0xFFFFFF, the next event will cause it to roll over to zero, set F1 or F2 bit respectively and generate interrupt by I1 I2 bit respectively. */
+    pseudo_bit_t	event_counter2[0x00020];/* Read/write event counter, counting events specified by EvCntl and EvCnt2 fields respectively. When the event counter reaches is maximum value of 0xFFFFFF, the next event will cause it to roll over to zero, set F1 or F2 bit respectively and generate interrupt by I1 I2 bit respectively. */
 /* -------------- */
 }; 
 
@@ -2455,7 +2455,7 @@ struct arbelprm_init_hca_st {	/* Little Endian */
     pseudo_bit_t	udp[0x00001];          /* UD Port Check Enable
                                                  0 - Port field in Address Vector is ignored
                                                  1 - HCA will check the port field in AV entry (fetched for UD descriptor) against the Port of the UD QP executing the descriptor. */
-    pseudo_bit_t	he[0x00001];           /* Host Endianess - Used for Atomic Operations
+    pseudo_bit_t	he[0x00001];           /* Host Endianness - Used for Atomic Operations
                                                  0 - Host is Little Endian
                                                  1 - Host is Big endian
                                                   */
@@ -3057,7 +3057,7 @@ struct arbelprm_event_queue_entry_st {	/* Little Endian */
     pseudo_bit_t	event_type[0x00008];   /* Event Type */
     pseudo_bit_t	reserved1[0x00008];
 /* -------------- */
-    pseudo_bit_t	event_data[6][0x00020];/* Delivers auxilary data to handle event. */
+    pseudo_bit_t	event_data[6][0x00020];/* Delivers auxiliary data to handle event. */
 /* -------------- */
     pseudo_bit_t	reserved2[0x00007];
     pseudo_bit_t	owner[0x00001];        /* Owner of the entry 
diff --git a/src/drivers/net/ath/ath5k/ath5k_desc.c b/src/drivers/net/ath/ath5k/ath5k_desc.c
index 30fe1c7..f9e493a 100644
--- a/src/drivers/net/ath/ath5k/ath5k_desc.c
+++ b/src/drivers/net/ath/ath5k/ath5k_desc.c
@@ -54,7 +54,7 @@ ath5k_hw_setup_2word_tx_desc(struct ath5k_hw *ah, struct ath5k_desc *desc,
 	/*
 	 * Validate input
 	 * - Zero retries don't make sense.
-	 * - A zero rate will put the HW into a mode where it continously sends
+	 * - A zero rate will put the HW into a mode where it continuously sends
 	 *   noise on the channel, so it is important to avoid this.
 	 */
 	if (tx_tries0 == 0) {
@@ -166,7 +166,7 @@ static int ath5k_hw_setup_4word_tx_desc(struct ath5k_hw *ah,
 	/*
 	 * Validate input
 	 * - Zero retries don't make sense.
-	 * - A zero rate will put the HW into a mode where it continously sends
+	 * - A zero rate will put the HW into a mode where it continuously sends
 	 *   noise on the channel, so it is important to avoid this.
 	 */
 	if (tx_tries0 == 0) {
@@ -244,7 +244,7 @@ static int ath5k_hw_setup_4word_tx_desc(struct ath5k_hw *ah,
 }
 
 /*
- * Proccess the tx status descriptor on 5210/5211
+ * Process the tx status descriptor on 5210/5211
  */
 static int ath5k_hw_proc_2word_tx_status(struct ath5k_hw *ah __unused,
 		struct ath5k_desc *desc, struct ath5k_tx_status *ts)
@@ -296,7 +296,7 @@ static int ath5k_hw_proc_2word_tx_status(struct ath5k_hw *ah __unused,
 }
 
 /*
- * Proccess a tx status descriptor on 5212
+ * Process a tx status descriptor on 5212
  */
 static int ath5k_hw_proc_4word_tx_status(struct ath5k_hw *ah __unused,
 		struct ath5k_desc *desc, struct ath5k_tx_status *ts)
@@ -387,7 +387,7 @@ static int ath5k_hw_setup_rx_desc(struct ath5k_hw *ah __unused,
 }
 
 /*
- * Proccess the rx status descriptor on 5210/5211
+ * Process the rx status descriptor on 5210/5211
  */
 static int ath5k_hw_proc_5210_rx_status(struct ath5k_hw *ah __unused,
 		struct ath5k_desc *desc, struct ath5k_rx_status *rs)
@@ -449,7 +449,7 @@ static int ath5k_hw_proc_5210_rx_status(struct ath5k_hw *ah __unused,
 }
 
 /*
- * Proccess the rx status descriptor on 5212
+ * Process the rx status descriptor on 5212
  */
 static int ath5k_hw_proc_5212_rx_status(struct ath5k_hw *ah __unused,
 		struct ath5k_desc *desc, struct ath5k_rx_status *rs)
diff --git a/src/drivers/net/ath/ath5k/ath5k_eeprom.c b/src/drivers/net/ath/ath5k/ath5k_eeprom.c
index 983d206..1e0d448 100644
--- a/src/drivers/net/ath/ath5k/ath5k_eeprom.c
+++ b/src/drivers/net/ath/ath5k/ath5k_eeprom.c
@@ -1070,7 +1070,7 @@ ath5k_eeprom_read_pcal_info_5112(struct ath5k_hw *ah, int mode)
  *
  * To recreate the curves we read here the points and interpolate
  * later. Note that in most cases only 2 (higher and lower) curves are
- * used (like RF5112) but vendors have the oportunity to include all
+ * used (like RF5112) but vendors have the opportunity to include all
  * 4 curves on eeprom. The final curve (higher power) has an extra
  * point for better accuracy like RF5112.
  */
@@ -1290,7 +1290,7 @@ ath5k_eeprom_read_pcal_info_2413(struct ath5k_hw *ah, int mode)
 			/*
 			 * Pd gain 0 is not the last pd gain
 			 * so it only has 2 pd points.
-			 * Continue wih pd gain 1.
+			 * Continue with pd gain 1.
 			 */
 			pcinfo->pwr_i[1] = (val >> 10) & 0x1f;
 
diff --git a/src/drivers/net/ath/ath5k/ath5k_pcu.c b/src/drivers/net/ath/ath5k/ath5k_pcu.c
index c8165da..933ad57 100644
--- a/src/drivers/net/ath/ath5k/ath5k_pcu.c
+++ b/src/drivers/net/ath/ath5k/ath5k_pcu.c
@@ -315,7 +315,7 @@ void ath5k_hw_set_associd(struct ath5k_hw *ah, const u8 *bssid, u16 assoc_id)
  * IFRAME-01:  0110
  *
  * An easy eye-inspeciton of this already should tell you that this frame
- * will not pass our check. This is beacuse the bssid_mask tells the
+ * will not pass our check. This is because the bssid_mask tells the
  * hardware to only look at the second least significant bit and the
  * common bit amongst the MAC and BSSIDs is 0, this frame has the 2nd LSB
  * as 1, which does not match 0.
@@ -463,7 +463,7 @@ void ath5k_hw_set_rx_filter(struct ath5k_hw *ah, u32 filter)
 	}
 
 	/*
-	 * The AR5210 uses promiscous mode to detect radar activity
+	 * The AR5210 uses promiscuous mode to detect radar activity
 	 */
 	if (ah->ah_version == AR5K_AR5210 &&
 			(filter & AR5K_RX_FILTER_RADARERR)) {
diff --git a/src/drivers/net/ath/ath5k/ath5k_phy.c b/src/drivers/net/ath/ath5k/ath5k_phy.c
index 7891d39..fa1c4c0 100644
--- a/src/drivers/net/ath/ath5k/ath5k_phy.c
+++ b/src/drivers/net/ath/ath5k/ath5k_phy.c
@@ -150,11 +150,11 @@ static unsigned int ath5k_hw_rfb_op(struct ath5k_hw *ah,
  * http://madwifi-project.org/ticket/1659
  * with various measurements and diagrams
  *
- * TODO: Deal with power drops due to probes by setting an apropriate
+ * TODO: Deal with power drops due to probes by setting an appropriate
  * tx power on the probe packets ! Make this part of the calibration process.
  */
 
-/* Initialize ah_gain durring attach */
+/* Initialize ah_gain during attach */
 int ath5k_hw_rfgain_opt_init(struct ath5k_hw *ah)
 {
 	/* Initialize the gain optimization values */
@@ -183,7 +183,7 @@ int ath5k_hw_rfgain_opt_init(struct ath5k_hw *ah)
  * tx power and a Peak to Average Power Detector (PAPD) will try
  * to measure the gain.
  *
- * TODO: Use propper tx power setting for the probe packet so
+ * TODO: Use proper tx power setting for the probe packet so
  * that we don't observe a serious power drop on the receiver
  *
  * XXX:  How about forcing a tx packet (bypassing PCU arbitrator etc)
@@ -843,7 +843,7 @@ int ath5k_channel_ok(struct ath5k_hw *ah, u16 freq, unsigned int flags)
 }
 
 /*
- * Convertion needed for RF5110
+ * Conversion needed for RF5110
  */
 static u32 ath5k_hw_rf5110_chan2athchan(struct net80211_channel *channel)
 {
@@ -881,7 +881,7 @@ static int ath5k_hw_rf5110_channel(struct ath5k_hw *ah,
 }
 
 /*
- * Convertion needed for 5111
+ * Conversion needed for 5111
  */
 static int ath5k_hw_rf5111_chan2athchan(unsigned int ieee,
 		struct ath5k_athchan_2ghz *athchan)
@@ -1573,7 +1573,7 @@ ath5k_create_power_curve(s16 pmin, s16 pmax,
 /*
  * Get the surrounding per-channel power calibration piers
  * for a given frequency so that we can interpolate between
- * them and come up with an apropriate dataset for our current
+ * them and come up with an appropriate dataset for our current
  * channel.
  */
 static void
@@ -1997,7 +1997,7 @@ ath5k_setup_pcdac_table(struct ath5k_hw *ah)
 /*
  * Set the gain boundaries and create final Power to PDADC table
  *
- * We can have up to 4 pd curves, we need to do a simmilar process
+ * We can have up to 4 pd curves, we need to do a similar process
  * as we do for RF5112. This time we don't have an edge_flag but we
  * set the gain boundaries on a separate register.
  */
@@ -2203,13 +2203,13 @@ ath5k_setup_channel_powertable(struct ath5k_hw *ah,
 	u32 target = channel->center_freq;
 	int pdg, i;
 
-	/* Get surounding freq piers for this channel */
+	/* Get surrounding freq piers for this channel */
 	ath5k_get_chan_pcal_surrounding_piers(ah, channel,
 						&pcinfo_L,
 						&pcinfo_R);
 
 	/* Loop over pd gain curves on
-	 * surounding freq piers by index */
+	 * surrounding freq piers by index */
 	for (pdg = 0; pdg < ee->ee_pd_gains[ee_mode]; pdg++) {
 
 		/* Fill curves in reverse order
@@ -2300,7 +2300,7 @@ ath5k_setup_channel_powertable(struct ath5k_hw *ah,
 		}
 
 		/* Interpolate between curves
-		 * of surounding freq piers to
+		 * of surrounding freq piers to
 		 * get the final curve for this
 		 * pd gain. Re-use tmpL for interpolation
 		 * output */
@@ -2324,7 +2324,7 @@ ath5k_setup_channel_powertable(struct ath5k_hw *ah,
 
 	/* Fill min and max power levels for this
 	 * channel by interpolating the values on
-	 * surounding channels to complete the dataset */
+	 * surrounding channels to complete the dataset */
 	ah->ah_txpower.txp_min_pwr = ath5k_get_interpolated_value(target,
 					(s16) pcinfo_L->freq,
 					(s16) pcinfo_R->freq,
@@ -2527,7 +2527,7 @@ ath5k_hw_txpower(struct ath5k_hw *ah, struct net80211_channel *channel,
 
 	/* FIXME: TPC scale reduction */
 
-	/* Get surounding channels for per-rate power table
+	/* Get surrounding channels for per-rate power table
 	 * calibration */
 	ath5k_get_rate_pcal_data(ah, channel, &rate_info);
 
diff --git a/src/drivers/net/ath/ath5k/ath5k_reset.c b/src/drivers/net/ath/ath5k/ath5k_reset.c
index 2f36a4e..87e6a93 100644
--- a/src/drivers/net/ath/ath5k/ath5k_reset.c
+++ b/src/drivers/net/ath/ath5k/ath5k_reset.c
@@ -152,7 +152,7 @@ static const unsigned int control_rates[] =
  * ath5k_hw_reset(). It seems all this is doing is setting an ACK timeout on
  * the hardware, based on current mode, for each rate. The rates which are
  * capable of short preamble (802.11b rates 2Mbps, 5.5Mbps, and 11Mbps) have
- * different rate code so we write their value twice (one for long preample
+ * different rate code so we write their value twice (one for long preamble
  * and one for short).
  *
  * Note: Band doesn't matter here, if we set the values for OFDM it works
diff --git a/src/drivers/net/ath/ath5k/eeprom.h b/src/drivers/net/ath/ath5k/eeprom.h
index da45433..7aa857f 100644
--- a/src/drivers/net/ath/ath5k/eeprom.h
+++ b/src/drivers/net/ath/ath5k/eeprom.h
@@ -251,7 +251,7 @@ enum ath5k_ctl_mode {
 /* Default CTL ids for the 3 main reg domains.
  * Atheros only uses these by default but vendors
  * can have up to 32 different CTLs for different
- * scenarios. Note that theese values are ORed with
+ * scenarios. Note that these values are ORed with
  * the mode id (above) so we can have up to 24 CTL
  * datasets out of these 3 main regdomains. That leaves
  * 8 ids that can be used by vendors and since 0x20 is
diff --git a/src/drivers/net/ath/ath5k/reg.h b/src/drivers/net/ath/ath5k/reg.h
index 7070d15..b207f75 100644
--- a/src/drivers/net/ath/ath5k/reg.h
+++ b/src/drivers/net/ath/ath5k/reg.h
@@ -133,8 +133,8 @@
  * As i can see in ar5k_ar5210_tx_start Reyk uses some of the values of BCR
  * for this register, so i guess TQ1V,TQ1FV and BDMAE have the same meaning
  * here and SNP/SNAP means "snapshot" (so this register gets synced with BCR).
- * So SNAPPEDBCRVALID sould also stand for "snapped BCR -values- valid", so i
- * renamed it to SNAPSHOTSVALID to make more sense. I realy have no idea what
+ * So SNAPPEDBCRVALID could also stand for "snapped BCR -values- valid", so i
+ * renamed it to SNAPSHOTSVALID to make more sense. I really have no idea what
  * else can it be. I also renamed SNPBCMD to SNPADHOC to match BCR.
  */
 #define AR5K_BSR		0x002c			/* Register Address */
@@ -284,7 +284,7 @@
  */
 #define AR5K_ISR		0x001c			/* Register Address [5210] */
 #define AR5K_PISR		0x0080			/* Register Address [5211+] */
-#define AR5K_ISR_RXOK		0x00000001	/* Frame successfuly recieved */
+#define AR5K_ISR_RXOK		0x00000001	/* Frame successfuly received */
 #define AR5K_ISR_RXDESC		0x00000002	/* RX descriptor request */
 #define AR5K_ISR_RXERR		0x00000004	/* Receive error */
 #define AR5K_ISR_RXNOFRM	0x00000008	/* No frame received (receive timeout) */
@@ -373,12 +373,12 @@
 /*
  * Interrupt Mask Registers
  *
- * As whith ISRs 5210 has one IMR (AR5K_IMR) and 5211/5212 has one primary
+ * As with ISRs 5210 has one IMR (AR5K_IMR) and 5211/5212 has one primary
  * (AR5K_PIMR) and 4 secondary IMRs (AR5K_SIMRx). Note that ISR/IMR flags match.
  */
 #define	AR5K_IMR		0x0020			/* Register Address [5210] */
 #define AR5K_PIMR		0x00a0			/* Register Address [5211+] */
-#define AR5K_IMR_RXOK		0x00000001	/* Frame successfuly recieved*/
+#define AR5K_IMR_RXOK		0x00000001	/* Frame successfuly received*/
 #define AR5K_IMR_RXDESC		0x00000002	/* RX descriptor request*/
 #define AR5K_IMR_RXERR		0x00000004	/* Receive error*/
 #define AR5K_IMR_RXNOFRM	0x00000008	/* No frame received (receive timeout)*/
@@ -896,7 +896,7 @@
 #define AR5K_PCICFG_SL_INTEN		0x00000800	/* Enable interrupts when asleep */
 #define AR5K_PCICFG_LED_BCTL		0x00001000	/* Led blink (?) [5210] */
 #define AR5K_PCICFG_RETRY_FIX		0x00001000	/* Enable pci core retry fix */
-#define AR5K_PCICFG_SL_INPEN		0x00002000	/* Sleep even whith pending interrupts*/
+#define AR5K_PCICFG_SL_INPEN		0x00002000	/* Sleep even with pending interrupts*/
 #define AR5K_PCICFG_SPWR_DN		0x00010000	/* Mask for power status */
 #define AR5K_PCICFG_LEDMODE		0x000e0000	/* Ledmode [5211+] */
 #define AR5K_PCICFG_LEDMODE_PROP	0x00000000	/* Blink on standard traffic [5211+] */
@@ -982,7 +982,7 @@
 #define AR5K_5414_CBCFG_BUF_DIS	0x10	/* Disable buffer */
 
 /*
- * PCI-E Power managment configuration
+ * PCI-E Power management configuration
  * and status register [5424+]
  */
 #define	AR5K_PCIE_PM_CTL		0x4068			/* Register address */
@@ -1064,7 +1064,7 @@
 /*
  * EEPROM command register
  */
-#define AR5K_EEPROM_CMD		0x6008			/* Register Addres */
+#define AR5K_EEPROM_CMD		0x6008			/* Register Address */
 #define AR5K_EEPROM_CMD_READ	0x00000001	/* EEPROM read */
 #define AR5K_EEPROM_CMD_WRITE	0x00000002	/* EEPROM write */
 #define AR5K_EEPROM_CMD_RESET	0x00000004	/* EEPROM reset */
@@ -1084,7 +1084,7 @@
 /*
  * EEPROM config register
  */
-#define AR5K_EEPROM_CFG			0x6010			/* Register Addres */
+#define AR5K_EEPROM_CFG			0x6010			/* Register Address */
 #define AR5K_EEPROM_CFG_SIZE		0x00000003		/* Size determination override */
 #define AR5K_EEPROM_CFG_SIZE_AUTO	0
 #define AR5K_EEPROM_CFG_SIZE_4KBIT	1
@@ -1126,7 +1126,7 @@
  * Second station id register (Upper 16 bits of MAC address + PCU settings)
  */
 #define AR5K_STA_ID1			0x8004			/* Register Address */
-#define	AR5K_STA_ID1_ADDR_U16		0x0000ffff	/* Upper 16 bits of MAC addres */
+#define	AR5K_STA_ID1_ADDR_U16		0x0000ffff	/* Upper 16 bits of MAC address */
 #define AR5K_STA_ID1_AP			0x00010000	/* Set AP mode */
 #define AR5K_STA_ID1_ADHOC		0x00020000	/* Set Ad-Hoc mode */
 #define AR5K_STA_ID1_PWR_SV		0x00040000	/* Power save reporting */
@@ -1397,7 +1397,7 @@
 #define AR5K_DIAG_SW_DIS_ENC		0x00000008	/* Disable encryption */
 #define AR5K_DIAG_SW_DIS_DEC		0x00000010	/* Disable decryption */
 #define AR5K_DIAG_SW_DIS_TX		0x00000020	/* Disable transmit [5210] */
-#define AR5K_DIAG_SW_DIS_RX_5210	0x00000040	/* Disable recieve */
+#define AR5K_DIAG_SW_DIS_RX_5210	0x00000040	/* Disable receive */
 #define AR5K_DIAG_SW_DIS_RX_5211	0x00000020
 #define	AR5K_DIAG_SW_DIS_RX		(ah->ah_version == AR5K_AR5210 ? \
 					AR5K_DIAG_SW_DIS_RX_5210 : AR5K_DIAG_SW_DIS_RX_5211)
diff --git a/src/drivers/infiniband/MT25408_PRM.h b/src/drivers/infiniband/MT25408_PRM.h
index cc248da..7c5306b 100644
--- a/src/drivers/infiniband/MT25408_PRM.h
+++ b/src/drivers/infiniband/MT25408_PRM.h
@@ -723,7 +723,7 @@ struct hermonprm_performance_monitors_st {	/* Little Endian */
 /* -------------- */
     pseudo_bit_t	event_counter1[0x00020];
 /* -------------- */
-    pseudo_bit_t	event_counter2[0x00020];/* Read/write event counter, counting events specified by EvCntl and EvCnt2 fields repsectively. When the event counter reaches is maximum value of 0xFFFFFF, the next event will cause it to roll over to zero, set F1 or F2 bit respectively and generate interrupt by I1 I2 bit respectively. */
+    pseudo_bit_t	event_counter2[0x00020];/* Read/write event counter, counting events specified by EvCntl and EvCnt2 fields respectively. When the event counter reaches is maximum value of 0xFFFFFF, the next event will cause it to roll over to zero, set F1 or F2 bit respectively and generate interrupt by I1 I2 bit respectively. */
 /* -------------- */
 }; 
 
@@ -2230,7 +2230,7 @@ struct hermonprm_query_dev_cap_st {	/* Little Endian */
 /* -------------- */
     pseudo_bit_t	altc_entry_sz[0x00010];/* Extended QPC entry size for the device
                                                  For the InfiniHost-III-EX MT25208 entry size is 32 bytes */
-    pseudo_bit_t	aux_entry_sz[0x00010]; /* Auxilary context entry size */
+    pseudo_bit_t	aux_entry_sz[0x00010]; /* Auxiliary context entry size */
 /* -------------- */
     pseudo_bit_t	cqc_entry_sz[0x00010]; /* CQC entry size for the device
                                                  For the InfiniHost-III-EX MT25208 entry size is 64 bytes */
@@ -2381,7 +2381,7 @@ struct hermonprm_init_hca_st {	/* Little Endian */
     pseudo_bit_t	udp[0x00001];          /* UD Port Check Enable
                                                  0 - Port field in Address Vector is ignored
                                                  1 - HCA will check the port field in AV entry (fetched for UD descriptor) against the Port of the UD QP executing the descriptor. */
-    pseudo_bit_t	he[0x00001];           /* Host Endianess - Used for Atomic Operations
+    pseudo_bit_t	he[0x00001];           /* Host Endianness - Used for Atomic Operations
                                                  0 - Host is Little Endian
                                                  1 - Host is Big endian
                                                   */
@@ -2965,7 +2965,7 @@ struct hermonprm_event_queue_entry_st {	/* Little Endian */
     pseudo_bit_t	event_type[0x00008];   /* Event Type */
     pseudo_bit_t	reserved1[0x00008];
 /* -------------- */
-    pseudo_bit_t	event_data[6][0x00020];/* Delivers auxilary data to handle event. */
+    pseudo_bit_t	event_data[6][0x00020];/* Delivers auxiliary data to handle event. */
 /* -------------- */
     pseudo_bit_t	reserved2[0x00007];
     pseudo_bit_t	owner[0x00001];        /* Owner of the entry 
-- 
1.7.10.4




More information about the ipxe-devel mailing list